@@ -8,20 +8,9 @@ import re
 from selenium.webdriver.common.by import By
 
 def check(web):
-    logger.info('正在自动审核')
-    #自动审核
-    try:
-        checkbox=web.driver.find_elements(By.NAME,'check_type')[0]
-        if not checkbox.is_selected():
-            checkbox.click()
-        logger.info('自动选择审核通过')
-        time.sleep(2)
-        web.driver.find_elements(By.ID,'qr')[0].click()
-        logger.info('已审核')
-        return True
-    except Exception as r:
-        logger.info('审核失败')
-        return False
+
+    return True
+    
 
 def wintersakura_upload(web,file1,record_path,qbinfo):
 
